# Managetests

Managetests è un semplice tool realizzato dal Gruppo Web di Ubuntu-it per la
gestione dei branch di test per il suo sito. Esso è integrato con GitLab, e
permette una sincronizzazione dei branch con i merge request presenti sul
repository. È anche altamente specifico per la nostra configurazione, quindi
potrebbe non funzionare in contesti differenti.

Managetests è rilasciato sotto licenza GNU-AGPL v3+.

## Dipendenze necessarie

Managetests necessita dei seguenti software per essere installato ed usato:

* Python 3 (apt: `python3`)
* PIP (apt: `python3-pip`)
* Virtualenv (apt: `python-virtualenv`, pip: `virtualenv`)
* Git (apt: `git`)
* NodeJS (apt: `nodejs nodejs-legacy`)
* NPM (apt: `npm`)
* Invoke (pip: `invoke`)

È possibile installarle con il seguente comando:

```
$ sudo apt install python3 python3-pip python-virtualenv git nodejs nodejs-legacy npm
$ sudo pip install invoke
```

## Inizializzazione di managetests

Managetests tiene tutti i file necessari al suo funzionamento in una directory
specifica. È possibile crearla con questo comando:

```
$ managetests -r path/to/directory init http://code.ubuntu-it.org/ubuntu-it-web/www
```

È necessario specificare il percorso della directory e l'indirizzo del
repository git. Una volta inizializzata la directory, bisogna modificare il
file di configurazione `config.json` presente in essa, in questo modo:

```json
{
    "gitlab-token": "YOUR-API-KEY",
    "gitlab-url": "http://code.ubuntu-it.org",
    "gitlab-project": "ubuntu-it-web/www",
    "hooks-token": "RANDOM-TOKEN",
    "keep-branches": [
        "master"
    ]
}
```

I parametri in esso sono i seguenti:

* `gitlab-token` è l'API key di GitLab del tuo account
* `gitlab-url` è l'URL dell'istanza GitLab
* `gitlab-project` è l'ID del progetto su GitLab
* `hooks-token` è il token necessario per inviare hook a managetests
* `keep-branches` è una lista di branch da caricare anche se non sono in una
  merge request (per esempio `master`)

## Esecuzione di managetests

Una volta configurato inizializzato e configurato managetests è possibile
eseguirlo, con questo comando:

```
$ managetests -r path/to/directory run
```

La prima volta che il comando viene eseguito sarà necessario aspettare che ogni
branch richiesto venga scaricato e preparato, e dopo ciò ogni branch verrà
eseguito.

## Integrazione con GitLab

Per poter integrare Managetests con GitLab, è necessario disporre di un account
con accesso al progetto, che verrà usato come bot per inviare commenti nei
merge request. Inoltre, è necessario configurare un webhook.

Per i commenti, è necessario prendere il secret token dalle impostazioni
dell'account che si vuole usare, ed inserirlo nel file `config.json` nella root
di managetests, alla chiave `gitlab-token`.

Per i webhook, è necessario prendere dal file `config.json` nella root di
managetests il valore della chiave `hooks-token` (casuale). Dopo aver fatto ciò
si può aggiungere il seguente webhook al progetto gitlab:

```
http://managetests.example.com/+hook/<hooks-token>
```

È necessario sostituire il dominio con il dominio della propria istanza, e
`<hooks-token>` con il token ottenuto prima. Il webhook è necessario che sia
configurato per ricevere i push e le merge request, tutto il resto verrà
ignorato.

## Generazione di una build

Per creare i pacchetti di managetests, è necessario aver installato
[pyinvoke](http://www.pyinvoke.org), ed eseguire questo comando:

```
$ invoke build
```

La prima esecuzione richiede una connessione ad internet per scaricare le
dipendenze richieste. Per rimuovere tutti i file generati:

```
$ invoke clean
```

## Hacking

Per contribuire a managetests è consigliata la creazione di un virtualenv per
lo sviluppo. È possibile crearlo con il seguente comando:

```
$ invoke devel
```

Una volta creato il virtualenv è disponibile in ``build/envs/devel``. Per
attivarlo bisogna ad ogni sessione di terminale eseguire:

```
$ source build/envs/devel/bin/activate
```
