# A program which manages Ubuntu-it's web test server
# Copyright (C) 2015  Pietro Albini <pietroalbini@ubuntu.com>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; witout even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import requests


class GitLabAPI:
    """Wrapper for the GitLab API"""

    def __init__(self, manager):
        self.manager = manager
        self.url = manager.config["gitlab-url"]
        self.token = manager.config["gitlab-token"]
        self.project_name = manager.config["gitlab-project"]
        self.project = self.project_id_of(self.project_name)

    def call(self, method, endpoint, params=None, data=None):
        """Make a raw call to the GitLab API"""
        if params == None:
            params = {}
        if data is None:
            data = {}

        url = self.url+"/api/v3/"+endpoint
        params["private_token"] = self.token

        print("API request: %s %s" % (method.upper(), url))
        response = requests.request(method, url, params=params, data=data)
        if response.status_code == 200:
            return response.json()
        return False

    def project_id_of(self, name):
        """Get the project ID of a specific project"""
        projects = self.call("get", "projects")
        for project in projects:
            if project["path_with_namespace"] == name:
                return project["id"]

        raise NameError("No project named %s" % name)

    def merge_requests(self):
        """Get all the merge requests of the project"""
        return self.call("get", "projects/%s/merge_requests" % self.project, {
            "state": "opened",
        })

    def merge_request(self, id):
        """Get a single merge request on the project"""
        return self.call("get", "projects/%s/merge_request/%s" % (
            self.project, id))

    def post_comment(self, id, text):
        """Post a comment on a merge request"""
        return self.call("post", "projects/%s/merge_request/%s/comments" % (
            self.project, id), data={"note": text})
