# A program which manages Ubuntu-it's web test server
# Copyright (C) 2015  Pietro Albini <pietroalbini@ubuntu.com>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; witout even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import pathlib


ROOT_DIR_VERSION = "1"


def is_root_valid(path):
    """Check if a root directory is valid"""
    path = pathlib.Path(path)

    if not (path.exists() and path.is_dir()):
        return False

    required_dirs = ["git", "branches"]
    required_files = ["config.json", "details.json", "version"]

    for dir in required_dirs:
        dir = path / dir
        if not (dir.exists() and dir.is_dir()):
            return False

    for file in required_files:
        file = path / file
        if not (file.exists() and file.is_file()):
            return False

    with (path / "version").open("r") as f:
        if f.read().strip() != ROOT_DIR_VERSION:
            return False

    return True
